@@ -8,8 +8,9 @@ sentry_hipchat.models
 
 from django import forms
 
-from sentry.conf import settings
-from sentry.plugins import Plugin
+from sentry.plugins.bases.notify import NotifyPlugin
+from sentry.utils import settings
+from sentry.conf import server
 
 import sentry_hipchat
 
@@ -18,7 +19,9 @@ import urllib2
 import json
 import logging
 
+
 COLORS = {
+    'ALERT': 'orange',
     'ERROR': 'red',
     'WARNING': 'yellow',
     'INFO': 'green',
@@ -34,7 +37,7 @@ class HipchatOptionsForm(forms.Form):
     include_project_name = forms.BooleanField(help_text='Include project name in message.', required=False)
 
 
-class HipchatMessage(Plugin):
+class HipchatMessage(NotifyPlugin):
     author = 'Xavier Ordoquy'
     author_url = 'https://github.com/linovia/sentry-hipchat'
     version = sentry_hipchat.VERSION
@@ -52,7 +55,22 @@ class HipchatMessage(Plugin):
     def is_configured(self, project):
         return all((self.get_option(k, project) for k in ('room', 'token')))
 
+    def on_alert(self, alert, **kwargs):
+        project = alert.project
+        token = self.get_option('token', project)
+        room = self.get_option('room', project)
+        notify = self.get_option('notify', project) or False
+        include_project_name = self.get_option('include_project_name', project) or False
+
+        if token and room:
+            self.send_payload(token, room, '[ALERT]%(project_name)s %(message)s %(link)s' % {
+                'project_name': (' <strong>%s</strong>' % project.name) if include_project_name else '',
+                'message': alert.message,
+                'link': alert.get_absolute_url(),
+            }, notify, color=COLORS['ALERT'])
+
     def post_process(self, group, event, is_new, is_sample, **kwargs):
+
         new_only = self.get_option('new_only', event.project)
         if new_only and not is_new:
             return
@@ -62,17 +80,15 @@ class HipchatMessage(Plugin):
         notify = self.get_option('notify', event.project) or False
         include_project_name = self.get_option('include_project_name', event.project) or False
         level = event.get_level_display().upper()
-        link = '<a href="%s/%s/group/%d/">(link)</a>' % (settings.URL_PREFIX, group.project.slug, group.id)
+        link = group.get_absolute_url()
 
         if token and room:
-            self.send_payload(token, room, '%(site)s[%(server)s]%(project_name)s %(message)s %(link)s' % {
-                    'server': event.server_name,
-                    'site': ('%s ' % event.site) if event.site else '',
-                    'project_name': (' <strong>%s</strong>' % event.project.name) if include_project_name else '',
-                    'message': event.message,
-                    'link': link,
-                },
-                notify, color=COLORS.get(level, 'purple'))
+            self.send_payload(token, room, '[%(level)s]%(project_name)s %(message)s [<a href="%(link)s">view on sentry</a>]' % {
+                'level': level,
+                'project_name': (' <strong>%s</strong>' % event.project.name) if include_project_name else '',
+                'message': event.message,
+                'link': link,
+            }, notify, color=COLORS.get(level, 'purple'))
 
     def send_payload(self, token, room, message, notify, color='red'):
         url = "https://api.hipchat.com/v1/rooms/message"
